==> albert_0.25.0.orig.tar.gz: albert-0.25.0/plugins/applications/i18n/applications_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Run desktop applications as described in the [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/).

Your current environment configuration results in the following applications directories: *__XDG_DATA_DIRS__*.</source>
        <translation type="vanished">Führen Sie Desktop-Anwendungen gemäß der [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/) aus.

Ihre aktuelle Umgebungskonfiguration führt zu den folgenden Anwendungsverzeichnissen: XDG_DATA_DIRS.</translation>
    </message>
    <message>
        <location filename="../src/configwidget_xdg.ui" line="21"/>
        <source>Run desktop applications as described in the [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/).</source>
        <translation>Führen Sie Desktop-Anwendungen gemäß der [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/) aus.</translation>
    </message>
    <message>
        <location filename="../src/configwidget_xdg.ui" line="39"/>
        <source>Ignore &apos;OnlyShowIn&apos;/&apos;NotShowIn&apos;</source>
        <translation>Ignoriere &apos;OnlyShowIn&apos;/&apos;NotShowIn&apos;</translation>
    </message>
    <message>
        <location filename="../src/configwidget_xdg.ui" line="53"/>
        <source>Use &apos;Exec&apos; for lookup</source>
        <translation>Verwende &apos;Exec&apos; für die Suche</translation>
    </message>
    <message>
        <location filename="../src/configwidget_xdg.ui" line="67"/>
        <source>Use &apos;Keywords&apos; for lookup</source>
        <translation>Verwende &apos;Keywords&apos; für die Suche</translation>
    </message>
    <message>
        <location filename="../src/configwidget_xdg.ui" line="81"/>
        <source>Use &apos;GenericName&apos; for lookup</source>
        <translation>Verwende &apos;GenericName&apos; für die Suche</translation>
    </message>
    <message>
        <location filename="../src/configwidget_xdg.ui" line="95"/>
        <source>Use non-localized &apos;Name&apos; for lookup</source>
        <translation>Den nicht lokalisierten &apos;Name&apos; für die Suche verwenden</translation>
    </message>
    <message>
        <location filename="../src/configwidget_mac.ui" line="9"/>
        <source>Index non-localized name</source>
        <translation>Den nicht lokalisierten Namen indexieren</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../src/plugin_mac.mm" line="83"/>
        <location filename="../src/plugin_xdg.cpp" line="281"/>
        <source>Launch app</source>
        <translation>Anwendung starten</translation>
    </message>
    <message>
        <location filename="../src/plugin_mac.mm" line="87"/>
        <source>Open terminal here</source>
        <translation>Terminal hier öffnen</translation>
    </message>
</context>
</TS>

==> albert_0.26.3.orig.tar.gz: albert-0.26.3/plugins/applications/i18n/applications_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ApplicationBase</name>
    <message>
        <source>Launch app</source>
        <translation type="obsolete">Anwendung starten</translation>
    </message>
    <message>
        <source>Launch application</source>
        <translation>Anwendung starten</translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Run desktop applications as described in the [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/).

Your current environment configuration results in the following applications directories: *__XDG_DATA_DIRS__*.</source>
        <translation type="vanished">Führen Sie Desktop-Anwendungen gemäß der [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/) aus.

Ihre aktuelle Umgebungskonfiguration führt zu den folgenden Anwendungsverzeichnissen: XDG_DATA_DIRS.</translation>
    </message>
    <message>
        <source>Run desktop applications as described in the [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/).</source>
        <translation>Führen Sie Desktop-Anwendungen gemäß der [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/) aus.</translation>
    </message>
    <message>
        <source>Ignore &apos;OnlyShowIn&apos;/&apos;NotShowIn&apos;</source>
        <translation>Ignoriere &apos;OnlyShowIn&apos;/&apos;NotShowIn&apos;</translation>
    </message>
    <message>
        <source>Use &apos;Exec&apos; for lookup</source>
        <translation>Verwende &apos;Exec&apos; für die Suche</translation>
    </message>
    <message>
        <source>Use &apos;Keywords&apos; for lookup</source>
        <translation>Verwende &apos;Keywords&apos; für die Suche</translation>
    </message>
    <message>
        <source>Use &apos;GenericName&apos; for lookup</source>
        <translation>Verwende &apos;GenericName&apos; für die Suche</translation>
    </message>
    <message>
        <source>Use non-localized &apos;Name&apos; for lookup</source>
        <translation>Den nicht lokalisierten &apos;Name&apos; für die Suche verwenden</translation>
    </message>
    <message>
        <source>Index non-localized name</source>
        <translation>Den nicht lokalisierten Namen indexieren</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Launch app</source>
        <translation type="vanished">Anwendung starten</translation>
    </message>
    <message>
        <source>Open terminal here</source>
        <translation type="vanished">Terminal hier öffnen</translation>
    </message>
    <message>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <source>Open desktop entry</source>
        <translation>Desktop Entry öffnen</translation>
    </message>
</context>
<context>
    <name>PluginBase</name>
    <message>
        <source>Report missing terminals &lt;a href=&quot;%1&quot;&gt;here&lt;/a&gt;.</source>
        <translation>Fehlend Terminals &lt;a href=&quot;%1&quot;&gt;melden&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>No terminal available.</source>
        <translation>Kein Terminal verfügbar.</translation>
    </message>
</context>
<context>
    <name>Terminal</name>
    <message>
        <source>Failed to run terminal with script: getpwuid(…) failed.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: getpwuid(…) fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Failed to run terminal with script: Script is empty.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: Skript ist leer.</translation>
    </message>
    <message>
        <source>Failed to run terminal with script: Could not create temporary script file.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: Temporäre Skriptdatei konnte nicht erstellt werden.</translation>
    </message>
</context>
</TS>
